@@ -1,8 +1,8 @@
 from .request import HttpRequest
 from .response import (
     HttpResponse,
-    HttpResponseServerError,
-    HttpResponseBadRequest,
-    HttpResponseNotFound,
+    HttpServerError,
+    HttpBadRequest,
+    HttpNotFound,
     JsonResponse
 )
